#!/usr/bin/perl

$toBuild = $ARGV[0];
$buildDir = $ARGV[1] . '/scripted';
$repoUrl = $ARGV[2];
$antLib = $ARGV[3];
$jbeProperites = $ARGV[4];
$scm = $ARGV[5];
$ant = $ARGV[6];
$buildToolkit = $ARGV[7];

sub run {
	my $cmd = shift(@_);

    $out = `$cmd`;
    $ret = $? >> 8;
    if ($ret != 0) {
        die("Failed ($ret): $cmd\n$out");
    }

    return $out;
}


# Clean out the old builds
run("rm -rf $buildDir");

run("mkdir -p $buildDir");


$baseArgs = "-u y -a n --non-interactive";

# Create a workspace, so that we avoid conflicts
print "Creating temporary workspace\n";
$wsName = "buildWorkspace-" . time();
$r = run("$scm $baseArgs create workspace -r $repoUrl -u ADMIN -s \"$toBuild\" $wsName");
$r =~ /^Workspace \(([^)]+)\)/;
$tmpWorkspace = $1;

# Load the workspace
print "Loading workspace $wsName\n";
$fullPath = "$buildDir/$wsName";
run("$scm $baseArgs load -r $repoUrl -u ADMIN -d $fullPath $tmpWorkspace");


sub publish_file($$$$) {
	my $file = shift(@_);
	my $component = shift(@_);
	my $label = shift(@_);
	my $contentType = shift(@_);
    
    print "Publishing $file ($component/$label)\n";
    run("$ant -lib $buildToolkit -buildfile $fullPath/$antLib/publish_file.ant -Djbe.properties=$jbeProperites -Dfilepath=$file -Dlabel=\"$label\" -DcomponentName=\"$component\" -DcontentType=$contentType");
}

sub publish_status($) {
	my $label = shift(@_);
    
    print "Setting status: $label\n";
    run("$ant -lib $buildToolkit -buildfile $fullPath/$antLib/publish_status.ant -Djbe.properties=$jbeProperites -Dlabel=\"$label\"");
}

publish_status("Generating zip");

run("zip -r $fullPath/everything.zip $fullPath");

publish_status("Uploading zip");

publish_file("$fullPath/everything.zip", "Some component", "With a label", "application/zip");

publish_status("Done upload");
